/****************************/
/* Error Code Definition    */
/****************************/
#define	ERR_BASE				0
#define	ERR_PORT				(ERR_BASE - 1)
#define	ERR_PRINTER				(ERR_BASE - 2)
#define	ERR_NOTFOUND			(ERR_BASE - 3)
#define	ERR_BUFFERSIZE			(ERR_BASE - 4)
#define	ERR_NOTSUPPORT			(ERR_BASE - 5)
#define	ERR_CHANNELNOTSUPPORT	(ERR_BASE - 6)
#define	ERR_HANDLE				(ERR_BASE - 7)
#define	ERR_BUFFERFULL			(ERR_BASE - 8)
#define	ERR_TIMEOUT				(ERR_BASE - 9)
#define	ERR_USERCANCEL			(ERR_BASE - 10)
#define	ERR_NOTBLOCK			(ERR_BASE - 11)
#define	ERR_INVALIDOPTIONDATA	(ERR_BASE - 12)
#define	ERR_INITIALIZE			(ERR_BASE - 13)
#define	ERR_OPTION				(ERR_BASE - 14)
#define	ERR_PARAMETER			(ERR_BASE - 15)
#define ERR_COMMUNICATION		(ERR_BASE - 16)
#define	ERR_BUSY				(ERR_BASE - 17)
#define ERR_INVALIDDEV			(ERR_BASE - 18)

#define ERR_COMMAND				(ERR_BASE - 100)
#define ERR_CHANNEL				(ERR_BASE - 101)
#define ERR_TEMPORARY			(ERR_BASE - 102)
#define ERR_DATAFILE			(ERR_BASE - 103)
#define ERR_INVALIDDATA			(ERR_BASE - 104)
#define ERR_MISTYPE				(ERR_BASE - 105)

/*******************************************************/
/* Printer path type                                   */
/*******************************************************/
#define TYPE_PORT		0
#define TYPE_PRINTER	1

/*******************************************************************************/
/* Printer Path Type - Port Name or                                            */
/*                      UF(User Friendly) Name such as "EPSON Stylus Pro 5000" */
/*******************************************************************************/
#define PAGE			0	// Use status1 in case of this type returned by GetDeviceID().
#define SIDM_1			1	// Use status2_common and charactercode1 in case of this type 
							// returned by GetDeviceID().
#define SIDM_2			2	// Use status2_common and charactercode2 in case of this type 
							// returned by GetDeviceID().
#define INJ_1			3	// Use status2_common in case of this type returned by GetDeviceID().
#define INJ_2			4	// Use status2_common and charactercode3 in case of this type 
							// returned by GetDeviceID().
#define STATUS_COMMON	5	// Use status2_common in case of this type returned by GetDeviceID().
#define NOTYPE			6	// Undefined type. Unusable.
#define COLOR_PAGE		7	// Use status1C in case of this type returned by GetDeviceID().
#define PAGE_2			8	// Use status2_PAGE in case of this type returned by GetDeviceID().
#define SIDM_3			9	// Use status2_common and mediastatus1 in case of this type 
							// returned by GetDeviceID().
#define COLOR_PAGE_2	10	// Use status2C in case of this type returned by GetDeviceID().
#define MC_PAGE_6		11	// Use status6MC in case of this type returned by GetDeviceID().

/*************************************************************************************/
/*  DeviceID Structure - Allocate memory of this structure in use of GetDeviceID().  */
/*                        GetDeviceID() sets each value.                             */
/*************************************************************************************/
struct deviceid {
	char mfg[256];		// Manufacturer (usually EPSON)
	char cmd[256];		// Supported Commands System
	char mdl[256];		// Model Name
	char cls[256];		// Device category (Printer)
	int prntype;		// Printer Type(defined above)
};

/***********************************************************************************/
/* Status Structures -  Allocate memory of one of the following STATUS structures, */
/*                      in case of using STATUS command with GetInformation().     */
/*                      Select one of the followings according to Printer Type     */
/***********************************************************************************/
// PAGE
struct status1 {
	unsigned char version;		// Structure Version(1 or 2 is returned)
	unsigned char printerid;	// Printer ID
	unsigned short status;		// Status code
	unsigned char jobname[21];	// The Job Name currently printing(specified name by STARTJOB command)
	int printpage;				// The number of printed papers of the Job currently printing.
	unsigned char tonerest;		// Toner remaining(%)
	char unitlife;				// Remaining life of photoconductor unit(%)
	unsigned char trayrest;		// Remaining paper of paper tray(%)
	char casset1rest;			// Remaining paper of paper cassette 1(%).  
								// -1 when cassette 1 is not installed.
	char casset2rest;			// Remaining paper of paper cassette 2(%).  
								// -1 when cassette 2 is not installed.
	short trayvol;				// Capacity of paper tray(number of sheets). 
								// -1 when it cannot be detected.
	short casset1vol;			// Capacity of paper cassette 1(number of sheets). 
								// -1 when it cannot be detected or cassette 1 is not installed.
	short casset2vol;			// Capacity of paper cassette 2(number of sheets). 
								// -1 when it cannot be detected or cassette 2 is not installed.
	unsigned char traysize;		// Paper size code of paper tray
	unsigned char casset1size;	// Paper size code of paper cassette 1. 0 when cassette 1 is not installed.
	unsigned char casset2size;	// Paper size code of paper cassette 2. 0 when cassette 2 is not installed.
	unsigned char dualprint;	// Duplex printing mechanism is installed or not. 1 if installed, 0 if not installed.
	char aslotid;				// Font card ID installed into IC slot A. -1 if not installed, 
								// 0 if the card other than font card installed.
	char bslotid;				// Font card ID installed into IC slot B. -1 if not installed, 
								// 0 if the card other than font card installed.
	char option;				// Installation state of option interface card.
								// Bit0: 1 if installed in slot 1, 0 otherwise
								// Bit1: 1 if installed in slot 2, 0 otherwise
	unsigned char memorysize;	// Installed memory size(MB)
	char casset3rest;			// Remaining paper of paper cassette 3(%).  -1 when cassette 3 is not installed.
	short casset3vol;			// Capacity of paper cassette 3(number of sheets). -1 when it cannot be detected
								// or cassette 3 is not installed.
	unsigned char casset3size;	// Paper size code of paper cassette 3. 0 when cassette 3 is not installed.
};

// COLOR_PAGE
struct status1C {
	unsigned char version;		// Structure Version(17 is returned)
	unsigned char printerid;	// Printer ID
	unsigned short status;		// Status code
	unsigned short memorysize;	// Installed memory size(MB)
	unsigned char ytonerest;	// Yellow toner remaining(%)
	unsigned char mtonerest;	// Magenta toner remaining(%)
	unsigned char ctonerest;	// Cyan toner remaining(%)
	unsigned char abandontoner;	// Consumption of wasted toner box(%)
	unsigned char oilroll;		// Oil roll remaining(%)
	char casset4rest;			// Remaining paper of paper cassette 4(%).  -1 when cassette 4 is not installed.
	short casset4vol;			// Capacity of paper cassette 4(number of sheets). -1 when it cannot be detected
								// or cassette 4 is not installed.
	unsigned char casset4size;	// Paper size code of paper cassette 4. 0 when cassette 4 is not installed.
	char reserved1[4];			// Reserved.
	unsigned char colorprint;	// Ratio of color printing(%)
	int totalprint;				// Total number of sheets printing
	int printpage;				// Total number of plane printing
	unsigned char btonerest;	// Black toner remaining(%)
	char unitlife;				// Remaining life of photoconductor unit(%)
	unsigned char trayrest;		// Remaining paper of paper tray(%)
	char casset1rest;			// Remaining paper of paper cassette 1(%).  -1 when cassette 1 is not installed.
	char casset2rest;			// Remaining paper of paper cassette 2(%).  -1 when cassette 2 is not installed.
	short trayvol;				// Capacity of paper tray(number of sheets). -1 when it cannot be detected.
	short casset1vol;			// Capacity of paper cassette 1(number of sheets). -1 when it cannot be detected
								// or cassette 1 is not installed.
	short casset2vol;			// Capacity of paper cassette 2(number of sheets). -1 when it cannot be detected
								// or cassette 2 is not installed.
	unsigned char traysize;		// Paper size code of paper tray
	unsigned char casset1size;	// Paper size code of paper cassette 1. 0 when cassette 1 is not installed.
	unsigned char casset2size;	// Paper size code of paper cassette 2. 0 when cassette 2 is not installed.
	unsigned char dualprint;	// Duplex printing mechanism is installed or not. 1 if installed, 0 if not installed.
	char aslotid;				// Font card ID installed into IC slot A. -1 if not installed, 
								// 0 if the card other than font card installed.
	char bslotid;				// Font card ID installed into IC slot B. -1 if not installed, 
								// 0 if the card other than font card installed.
	char option;				// Installation state of option interface card.
								// Bit0: 1 if installed in slot 1, 0 otherwise
								// Bit1: 1 if installed in slot 2, 0 otherwise
	char reserved2;				// Reserved
	char casset3rest;			// Remaining paper of paper cassette 3(%).  -1 when cassette 3 is not installed.
	short casset3vol;			// Capacity of paper cassette 3(number of sheets). -1 when it cannot be detected
								// or cassette 3 is not installed.
	unsigned char casset3size;	// Paper size code of paper cassette 3. 0 when cassette 3 is not installed.
};

// PAGE_2
struct status2_PAGE {
	unsigned char version;			// Structure Version(33 or 34 is returned)
	unsigned char printerid;		// Printer ID
	unsigned short status;			// Status code
	unsigned short memorysize;		// Installed memory size(MB)
	unsigned char traypapertype;	// Type of Paper tray
	unsigned char casset1papertype;	// Type of Paper cassette 1
	unsigned char casset2papertype;	// Type of Paper cassette 2
	unsigned char casset3papertype;	// Type of Paper cassette 3
	unsigned char casset4papertype;	// Type of Paper cassette 4
	char casset4rest;				// Remaining paper of paper cassette 4(%).  -1 when cassette 4 is not installed.
	short casset4vol;				// Capacity of paper cassette 4(number of sheets). -1 when it cannot be detected
									// or cassette 4 is not installed.
	unsigned char casset4size;		// Paper size code of paper cassette 4. 0 when cassette 4 is not installed.
	char casset5rest;				// Remaining paper of paper cassette 5(%).  -1 when cassette 5 is not installed.
	short casset5vol;				// Capacity of paper cassette 5(number of sheets). -1 when it cannot be detected
									// or cassette 5 is not installed.
	unsigned char casset5size;		// Paper size code of paper cassette 5. 0 when cassette 5 is not installed.
	unsigned char casset5papertype;	// Type of Paper cassette 5
	int totalprint;					// Total number of sheets printing
	char faceup;					// Status of faceup
	char mfmode;					// Working mode of Multi-bin/Finisher
	char mftype;					// Type of Multi-bin/Finisher
	char reserved1;					// Reserved
	unsigned char btonerest;		// Black toner remaining(%)
	char unitlife;					// Remaining life of photoconductor unit(%)
	unsigned char trayrest;			// Remaining paper of paper tray(%)
	char casset1rest;				// Remaining paper of paper cassette 1(%).  -1 when cassette 1 is not installed.
	char casset2rest;				// Remaining paper of paper cassette 2(%).  -1 when cassette 2 is not installed.
	short trayvol;					// Capacity of paper tray(number of sheets). -1 when it cannot be detected.
	short casset1vol;				// Capacity of paper cassette 1(number of sheets). -1 when it cannot be detected
									// or cassette 1 is not installed.
	short casset2vol;				// Capacity of paper cassette 2(number of sheets). -1 when it cannot be detected
									// or cassette 2 is not installed.
	unsigned char traysize;			// Paper size code of paper tray
	unsigned char casset1size;		// Paper size code of paper cassette 1. 0 when cassette 1 is not installed.
	unsigned char casset2size;		// Paper size code of paper cassette 2. 0 when cassette 1 is not installed.
	unsigned char dualprint;		// Duplex printing mechanism is installed or not. 
									// 1 if installed, 0 if not installed.
	char aslotid;					// Font card ID installed into IC slot A. -1 if not installed, 
									// 0 if the card other than font card installed.
	char bslotid;					// Font card ID installed into IC slot B. -1 if not installed, 
									// 0 if the card other than font card installed.
	char option;					// Installation state of option interface card.
									// Bit0: 1 if installed in slot 1, 0 otherwise
									// Bit1: 1 if installed in slot 2, 0 otherwise
	char reserved2;					// Reserved
	char casset3rest;				// Remaining paper of paper cassette 3(%).  -1 when cassette 3 is not installed.
	short casset3vol;				// Capacity of paper cassette 3(number of sheets). -1 when it cannot be detected
									// or cassette 3 is not installed.
	unsigned char casset3size;		// Paper size code of paper cassette 3. 0 when cassette 3 is not installed.
};

// COLOR_PAGE_2
struct status2C {
	unsigned char version;			// Structure Version(49 is returned)
	unsigned char printerid;		// Printer ID
	unsigned short status;			// Status code
	unsigned short memorysize;		// Installed memory size(MB)
	unsigned char ytonerest;		// Yellow toner remaining(%)
	unsigned char mtonerest;		// Magenta toner remaining(%)
	unsigned char ctonerest;		// Cyan toner remaining(%)
	unsigned char abandontoner;		// Consumption of wasted toner box(%)
	unsigned char oilroll;			// Oil roll remaining(%)
	char casset4rest;				// Remaining paper of paper cassette 4(%).  -1 when cassette 4 is not installed.
	short casset4vol;				// Capacity of paper cassette 4(number of sheets). -1 when it cannot be detected
									// or cassette 4 is not installed.
	unsigned char casset4size;		// Paper size code of paper cassette 4. 0 when cassette 4 is not installed.
	char reserved1;					// Reserved.
	unsigned char traypapertype;	// Type of Paper tray
	unsigned char casset1papertype;	// Type of Paper cassette 1
	unsigned char casset2papertype;	// Type of Paper cassette 2
	unsigned char colorprint;		// Ratio of color printing(%)
	int totalprint;					// Total number of sheets printing
	int colorprintpage;				// Total number of color printing
	unsigned char btonerest;		// Black toner remaining(%)
	char unitlife;					// Remaining life of photoconductor unit(%)
	unsigned char trayrest;			// Remaining paper of paper tray(%)
	char casset1rest;				// Remaining paper of paper cassette 1(%).  -1 when cassette 1 is not installed.
	char casset2rest;				// Remaining paper of paper cassette 2(%).  -1 when cassette 2 is not installed.
	short trayvol;					// Capacity of paper tray(number of sheets). -1 when it cannot be detected.
	short casset1vol;				// Remaining paper of paper cassette 1(%).  -1 when cassette 1 is not installed.
	short casset2vol;				// Remaining paper of paper cassette 2(%).  -1 when cassette 2 is not installed.
	unsigned char traysize;			// Paper size code of paper tray
	unsigned char casset1size;		// Paper size code of paper cassette 1. 0 when cassette 1 is not installed.
	unsigned char casset2size;		// Paper size code of paper cassette 2. 0 when cassette 1 is not installed.
	unsigned char casset4papertype;	// Type of Paper cassette 4
	char aslotid;					// Font card ID installed into IC slot A. -1 if not installed, 
									// 0 if the card other than font card installed.
	char bslotid;					// Font card ID installed into IC slot B. -1 if not installed, 
									// 0 if the card other than font card installed.
	char option;					// Installation state of option interface card.
									// Bit0: 1 if installed in slot 1, 0 otherwise
									// Bit1: 1 if installed in slot 2, 0 otherwise
	unsigned char casset3papertype;	// Type of Paper cassette 3
	char casset3rest;				// Remaining paper of paper cassette 3(%).  -1 when cassette 3 is not installed.
	short casset3vol;				// Capacity of paper cassette 3(number of sheets). -1 when it cannot be detected
									// or cassette 3 is not installed.
	unsigned char casset3size;		// Paper size code of paper cassette 3. 0 when cassette 3 is not installed.
};

// MC_PAGE_6 (MONOCHROME and COLOR)
struct status6MC {
	unsigned char version;			// Structure Version(97 or 98 is returned)
	unsigned char printerid;		// Printer ID
	unsigned short status;			// Status code
	unsigned short memorysize;		// Installed memory size(MB)
	short printstatus;				// Printing status
	unsigned short warningstatus;	// Supply warning status
	char btonerest;					// Black toner remaining(%)
	char ctonerest;					// Cyan toner remaining(%)
	char mtonerest;					// Magenta toner remaining(%)
	char ytonerest;					// Yellow toner remaining(%)
	char abandontoner;				// Consumption of wasted toner box(%)
	char oilroll;					// Oil roll remaining(%)
	char unitlife;					// Remaining life of Black photoconductor unit(%)
	char cunitlife;					// Remaining life of Cyan photoconductor unit(%)
	char munitlife;					// Remaining life of Magenta photoconductor unit(%)
	char yunitlife;					// Remaining life of Yellow photoconductor unit(%)
	unsigned char trayrest;			// Remaining paper of paper tray(%)
	char trayvol;					// Capacity of paper tray(number of sheets). -1 when it cannot be detected.
	unsigned char traysize;			// Paper size code of paper tray
	unsigned char traypapertype;	// Type of Paper tray
	char casset1rest;				// Remaining paper of paper cassette 1(%).  -1 when cassette 1 is not installed.
	char casset1vol;				// Remaining paper of paper cassette 1(%).  -1 when cassette 1 is not installed.
	unsigned char casset1size;		// Paper size code of paper cassette 1. 0 when cassette 1 is not installed.
	unsigned char casset1papertype;	// Type of Paper cassette 1
	char casset2rest;				// Remaining paper of paper cassette 2(%).  -1 when cassette 2 is not installed.
	char casset2vol;				// Remaining paper of paper cassette 2(%).  -1 when cassette 2 is not installed.
	unsigned char casset2size;		// Paper size code of paper cassette 2. 0 when cassette 1 is not installed.
	unsigned char casset2papertype;	// Type of Paper cassette 2
	char casset3rest;				// Remaining paper of paper cassette 3(%).  -1 when cassette 3 is not installed.
	char casset3vol;				// Capacity of paper cassette 3(number of sheets). -1 when it cannot be detected
									// or cassette 3 is not installed.
	unsigned char casset3size;		// Paper size code of paper cassette 3. 0 when cassette 3 is not installed.
	unsigned char casset3papertype;	// Type of Paper cassette 3
	char casset4rest;				// Remaining paper of paper cassette 4(%).  -1 when cassette 4 is not installed.
	char casset4vol;				// Capacity of paper cassette 4(number of sheets). -1 when it cannot be detected
									// or cassette 4 is not installed.
	unsigned char casset4size;		// Paper size code of paper cassette 4. 0 when cassette 4 is not installed.
	unsigned char casset4papertype;	// Type of Paper cassette 4
	int totalprint;					// Total number of sheets printing
	int colorprintpage;				// Total number of color printing
	char option;					// Installation state of option interface card.
	short reserve;					// Reserve

};

/*************************************************************************/
/* Ink Quantity Information - involved in status2_common structure       */
/*************************************************************************/
struct colorrest {
	char  blackrest;				// Black ink remaining(%)
	char  cyanrest;					// CYAN ink remaining(%)
	char  magentarest;				// MAGENTA ink remaining(%)
	char  yellowrest;				// YELLOW ink remaining(%)
	char  lightcyanrest;			// LIGHTCYAN ink remaining(%)
	char  lightmagentarest;			// LIGHTMAGENNTA ink remaining(%)
	char  grayrest;					// GRAY ink remaining(%)
};

/*************************************************************************/
/* Ink Capacity Information - involved in status2_common structure       */
/*************************************************************************/
struct colorcapacity {
	char  blackcapacity;			// Black ink capacity(%)
	char  cyancapacity;				// CYAN ink capacity(%)
	char  magentacapacity;			// MAGENTA ink capacity(%)
	char  yellowcapacity;			// YELLOW ink capacity(%)
	char  lightcyancapacity;		// LIGHTCYAN ink capacity(%)
	char  lightmagentacapacity;		// LIGHTMAGENNTA ink capacity(%)
};

/*************************************************************************/
/* Picture element deflection information                                */
/*                              - involved in status2_common structure   */
/*************************************************************************/
struct headdeflection {
	char  blackdeflection;			// Black deflection information
	char  cyandeflection;			// CYAN deflection information
	char  magentadeflection;		// MAGENTA deflection information
	char  yellowdeflection;			// YELLOW deflection information
	char  lightcyandeflection;		// LIGHTCYAN deflection information
	char  lightmagentadeflection;	// LIGHTMAGENNTA deflection information
	char  graydeflection;			// GRAY or Matte Black deflection information
};

/************************************************************************/
/* Warning Information - involved in status2_common structure          */
/************************************************************************/
struct warningcode {
	char papernearend1;				// indicate paper of CSF BIN1 is low, if value is 00h.
	char papernearend2;				// indicate paper of CSF BIN1 is low, if value is 01h.
	char  blacklow;					// indicate BLACK ink is low, if value is 10h.
	char  cyanlow;					// indicate CYAN ink is low, if value is 11h.
	char  magentalow;				// indicate MAGENTA ink is low, if value is 12h.
	char  yellowlow;				// indicate YELLOW ink is low, if value is 13h.
	char  lightcyanlow;				// indicate LIGHTCYAN ink is low, if value is 14h.
	char  lightmagentalow;			// indicate LIGHTMAGENTA ink is low, if value is 15h.
};


/*********************************************/
/* Status structure for IJP, SIDM            */
/*********************************************/
// SIDM_1,SIDM_2,INJ_1,INJ_2,SIDM_3
struct  status2_common {
	char  statuscode;				// Status code
	char  errcode;					// Error code
	struct colorrest  color;		// Color ink remaining(see above)
	struct colorcapacity capacity;	// Color ink capacity(see above)
	struct headdeflection deflection;//Deflection information(see above)
	struct warningcode warning;		// Each warning code(see above)
	char  selfprintcode;			// Self printing
	char  csfpaperbin1;				// Paper remaining of CSF BIN1(%)
	char  csfpaperbin2;				// Paper remaining of CSF BIN2(%)
	short paperpath;				// Selected paper path
	char revision;					// Firmware revision
	void *exclusivecode;			// pointer to additional information below
									// point to one of charactercode1,2,3,mediastatus1
};
 
/***********************************************************************************************/
/* status2_common additional Information                                                       */
/*                       - pointed by exclusivecode involved in status2_common                 */
/***********************************************************************************************/
// SIDM_1
struct  charactercode1 {
	unsigned  char  version;		// Structure version(Fixed value is 01)
	unsigned  char  yy;				// Started year(In case of XX97, value is 97)
	unsigned  char  mm;				// Started month
	unsigned  char  dd;				// Started date
	unsigned  int    printline;		// Total printed lines
	unsigned  short totaltime;		// Total elapsed time
	unsigned short csfbin1size;		// Paper size of CSF Bin1
	unsigned short csfbin2size;		// Paper size of CSF Bin2
	unsigned short csfbin3size;		// Paper size of CSF Bin3
	unsigned short paperwidth;		// Width of continuous paper 
};

// SIDM_2
typedef struct  charactercode2 {
	unsigned  char  version;		// Structure version(Fixed value is 02)
	unsigned  char  yy;				// Started year(In case of XX97, value is 97)
	unsigned  char  mm;				// Started month
	unsigned  char  dd;				// Started date
	unsigned  int    printline;		// Total printed lines
	unsigned  short totaltime;		// Total elapsed time
	unsigned  int resetprintline;	// Total printed lines after ribbon was changed to new one
} CDCODE_2;

// INJ_1
// No exclusivecode

// INJ_2
struct  charactercode3 {
	unsigned char  version;			// Structure version(Fixed value is 03)
	unsigned short csfbin1size;		// Paper size of CSF Bin1
	unsigned char csfbin1type;		// Paper type of CSF Bin1
	unsigned char  csfbin1rest;		// Paper remaining of CSF BIN1(%)
	unsigned short csfbin2size;		// Paper size of CSF Bin2
	unsigned char csfbin2type;		// Paper type of CSF Bin2
	unsigned char  csfbin2rest;		// Paper remaining of CSF BIN2(%)
	unsigned char  simmvol;			// SIMM size(Mbyte)
};

// SIDM_3
struct  mediastatus1 {
	CDCODE_2 CDcode;				// charactercode2 information
	short	mediaregistration1;		// status of registered paper 1
	short	mediaregistration2;		// status of registered paper 2
	short	mediaregistration3;		// status of registered paper 3
	short	mediaregistration4;		// status of registered paper 4
	short	mediaregistration5;		// status of registered paper 5
	short	mediaregistration6;		// status of registered paper 6
	short	mediaregistration7;		// status of registered paper 7
	short	mediaregistration8;		// status of registered paper 8
};

/***************************************************************************/
/* CM Paper Information - only for SIDM                                    */
/*                         used by GetInformation(), SetInformation()      */
/***************************************************************************/
struct cmdata {
	char number;					// Paper number
	char name[21];					// Paper name
	char papercategory;				// Paper equipment(Continuous, CSF,...)
	char paperpath;					// Paper location(Rear, Front, Bin1, Bin2..)
	unsigned short vertical;		// Paper length in Vertical
	unsigned short horizontal;		// Paper length in Horizontal
	char kindofpaper;				// Paper type(Post card, Envelope,...)
	char status;					// Paper status
};

/********************************************************************/
/* Stringcommand Structure  - only for MR command feature with SIDM */
/********************************************************************/
typedef struct stringcommand {
    char command[1024];				// String type command(NULL ended)
	int reserved1;					// Reserved 1
	int reserved2;					// Reserved 2
} STRINGCOMMAND, *LPSTRINGCOMMAND;

